@@ -5,7 +5,7 @@ import numpy as np
 import pandas as pd
 from typing import Any, Callable, Dict, List, Set, Tuple
 
-from augur.dates import numeric_date, is_date_ambiguous, get_numerical_dates
+from augur.dates import is_date_ambiguous, get_numerical_dates
 from augur.errors import AugurError
 from augur.io.metadata import METADATA_DATE_COLUMN
 from augur.io.print import print_err
@@ -13,12 +13,6 @@ from augur.io.vcf import is_vcf as filename_is_vcf
 from augur.utils import read_strains
 from . import constants
 
-try:
-    # python ≥3.8 only
-    from typing import Literal  # type: ignore
-except ImportError:
-    from typing_extensions import Literal  # type: ignore
-
 try:
     # pandas ≥1.5.0 only
     PandasUndefinedVariableError = pd.errors.UndefinedVariableError  # type: ignore
@@ -190,11 +184,27 @@ def filter_by_query(metadata, query) -> FilterFunctionReturn:
     set()
 
     """
-    # Try converting all queried columns to numeric.
-    for column in extract_variables(query).intersection(metadata.columns):
-        metadata[column] = pd.to_numeric(metadata[column], errors='ignore')
+    # Create a copy to prevent modification of the original DataFrame.
+    metadata_copy = metadata.copy()
 
-    return set(metadata.query(query).index.values)
+    # Support numeric comparisons in query strings.
+    #
+    # The built-in data type inference when loading the DataFrame does not
+    # support nullable numeric columns, so numeric comparisons won't work on
+    # those columns. pd.to_numeric does proper conversion on those columns, and
+    # will not make any changes to columns with other values.
+    #
+    # TODO: Parse the query string and apply conversion only to columns used for
+    # numeric comparison. Pandas does not expose the API used to parse the query
+    # string internally, so this is non-trivial and requires a bit of
+    # reverse-engineering. Commit 2ead5b3e3306dc1100b49eb774287496018122d9 got
+    # halfway there but had issues so it was reverted.
+    #
+    # TODO: Try boolean conversion?
+    for column in metadata_copy.columns:
+        metadata_copy[column] = pd.to_numeric(metadata_copy[column], errors='ignore')
+
+    return set(metadata_copy.query(query).index.values)
 
 
 def filter_by_ambiguous_date(metadata, date_column, ambiguity) -> FilterFunctionReturn:
@@ -264,6 +274,7 @@ def filter_by_min_date(metadata, date_column, min_date) -> FilterFunctionReturn:
 
     Examples
     --------
+    >>> from augur.dates import numeric_date
     >>> metadata = pd.DataFrame([{"region": "Africa", "date": "2020-01-01"}, {"region": "Europe", "date": "2020-01-02"}], index=["strain1", "strain2"])
     >>> filter_by_min_date(metadata, date_column="date", min_date=numeric_date("2020-01-02"))
     {'strain2'}
@@ -304,6 +315,7 @@ def filter_by_max_date(metadata, date_column, max_date) -> FilterFunctionReturn:
 
     Examples
     --------
+    >>> from augur.dates import numeric_date
     >>> metadata = pd.DataFrame([{"region": "Africa", "date": "2020-01-01"}, {"region": "Europe", "date": "2020-01-02"}], index=["strain1", "strain2"])
     >>> filter_by_max_date(metadata, date_column="date", max_date=numeric_date("2020-01-01"))
     {'strain1'}
@@ -667,6 +679,7 @@ def apply_filters(metadata, exclude_by: List[FilterOption], include_by: List[Fil
 
     Examples
     --------
+    >>> from augur.dates import numeric_date
     >>> metadata = pd.DataFrame([{"region": "Africa", "date": "2020-01-01"}, {"region": "Europe", "date": "2020-10-02"}, {"region": "North America", "date": "2020-01-01"}], index=["strain1", "strain2", "strain3"])
     >>> exclude_by = [(filter_by_min_date, {"date_column": "date", "min_date": numeric_date("2020-04-01")})]
     >>> include_by = [(force_include_where, {"include_where": "region=Africa"})]
@@ -810,29 +823,3 @@ def _filter_kwargs_to_str(kwargs: FilterFunctionKwargs):
         kwarg_list.append((key, value))
 
     return json.dumps(kwarg_list)
-
-
-# From https://stackoverflow.com/a/76536356
-def extract_variables(pandas_query: str):
-    """Extract variable names used in a pandas query string."""
-
-    # Track variables in a dictionary to be used as a dictionary of globals.
-    variables: Dict[str, Literal[None]] = {}
-
-    while True:
-        try:
-            # Try creating a Expr object with the query string and dictionary of globals.
-            # This will raise an error as long as the dictionary of globals is incomplete.
-            env = pd.core.computation.scope.ensure_scope(level=0, global_dict=variables)
-            pd.core.computation.expr.Expr(pandas_query, env=env)
-
-            # Exit the loop when evaluation is successful.
-            break
-        except PandasUndefinedVariableError as e:
-            # This relies on the format defined here: https://github.com/pandas-dev/pandas/blob/965ceca9fd796940050d6fc817707bba1c4f9bff/pandas/errors/__init__.py#L401
-            name = re.findall("name '(.+?)' is not defined", str(e))[0]
-
-            # Add the name to the globals dictionary with a dummy value.
-            variables[name] = None
-
-    return set(variables.keys())
