@@ -2,6 +2,6 @@
 """
 # Functions and variables exposed here are part of Augur's public Python API.
 # To use functions internally, import directly from the submodule.
-from .file import open_file
-from .metadata import read_metadata
-from .sequences import read_sequences, write_sequences
+from .file import open_file  # noqa: F401
+from .metadata import read_metadata  # noqa: F401
+from .sequences import read_sequences, write_sequences  # noqa: F401
