@@ -15,7 +15,7 @@ mutations are output to a node-data JSON file.
 
 import os, sys
 import numpy as np
-from Bio import SeqIO, SeqFeature, Seq, SeqRecord, Phylo
+from Bio import SeqIO, Seq, SeqRecord, Phylo
 from .io.vcf import write_VCF_translation
 from .utils import read_node_data, load_features, write_json, get_json_name
 from treetime.vcf_utils import read_vcf
