@@ -1,8 +1,7 @@
 from collections import defaultdict
-from io import TextIOWrapper
 import functools
-from pkg_resources import resource_stream
 
+from augur.data import as_file
 from augur.util_support.color_parser_line import ColorParserLine
 
 
@@ -17,8 +16,8 @@ class ColorParser:
         colors = {}
 
         if self.use_defaults:
-            with resource_stream("augur", "data/colors.tsv") as stream:
-                with TextIOWrapper(stream, "utf-8") as defaults:
+            with as_file("colors.tsv") as file:
+                with open(file, encoding="utf-8") as defaults:
                     colors = {**colors, **self.parse_file(defaults)}
 
         if self.mapping_filename:
